@@ -3,6 +3,8 @@
 ROOT=$(cd "$(dirname "$0")/../" && pwd)
 
 if [[ $# -eq 0 ]]; then
+    $0 5.40.0 5-40 x86_64
+    $0 5.40.0 5-40 arm64
     $0 5.38.2 5-38 x86_64
     $0 5.38.2 5-38 arm64
     exit 0
